@@ -117,7 +117,7 @@ require Exporter;
 
 @ISA     = qw(Exporter AutoLoader);
 @EXPORT  = qw( );
-$VERSION = '1.24';
+$VERSION = '1.26';
 
 ######################################################################
 # Globals: Debug and the mysterious waitpid nohang constant.
@@ -516,6 +516,10 @@ signal (SIGTERM if undefined).
 sub DESTROY {
     my $self = shift;
 
+    # Localize special variables so that the exit status from waitpid
+    # doesn't leak out, causing exit status to be incorrect.
+    local( $., $@, $!, $^E, $? );
+
     # Processes never started don't have to be cleaned up in
     # any special way.
     return unless $self->pid();
@@ -598,6 +602,10 @@ sub wait {
 ######################################################################
 sub THE_REAPER {
 
+    # Localize special variables so that the exit status from waitpid
+    # doesn't leak out, causing exit status to be incorrect.
+    local( $., $@, $!, $^E, $? );
+
     my $child;
     my $now = time();
 
@@ -722,6 +730,11 @@ repeatedly with the I<poll> routine after sending the signal.
 I'd recommend using perl 5.6.0 although it might also run with 5.003
 -- if you don't have it, this is the time to upgrade!
 
+LEGALESE
+Copyright 1996 by Mike Schilli, all rights reserved. This program is
+free software, you can redistribute it and/or modify it under the same
+terms as Perl itself.
+
 =head1 AUTHOR
 
 Michael Schilli <michael@perlmeister.com>
@@ -744,4 +757,6 @@ Chip Capelik contributed a patch with the wait() method.
 
 Jeff Holt provided a patch for time tracking with t0() and t1().
 
+Brad Cavanagh fixed RT33440 (unreliable $?)
+
 =cut
